- normalize
if TRUE, normalize U and V to uncorrelated Gaussian U and upper triangular V with positive diagonal
- maxiter
maximum number of iterations
- nstep
number of IRWLS steps in each inner loop of AIRWLS
- stepsize
step-size parameter scaling each IRWLS step
- eps
how much shrinkage has to be introduced on extreme predictions lying outside of the data range
- nafill
how frequently the NA values are filled, by default NA values are filled at each iteration of the algorithm
- tol
tolerance threshold for the stopping criterion
- damping
regularization parameter which is added to the diagonal of the Hessian to ensure numerical stability
- verbose
if TRUE, print the optimization status (default TRUE)
- frequency
how often the optimization status is printed (only if verbose=TRUE)
- parallel
if TRUE, allows for parallel computing using the C++ library OpenMP
- nthreads
number of cores to be used in parallel (only if parallel=TRUE)