Learn R Programming

sgdGMF (version 1.0)

vglm.fit.coef: Estimate the coefficients of a vector generalized linear model

Description

Estimate the coefficients of a vector generalized linear model via parallel iterative re-weighted least squares. Computations can be performed in parallel to speed up the execution.

Usage

vglm.fit.coef(
  Y,
  X,
  family = gaussian(),
  weights = NULL,
  offset = NULL,
  parallel = FALSE,
  nthreads = 1,
  clust = NULL
)

Arguments

Y

\(n \times m\) matrix of response variables

X

\(n \times p\) matrix of covariates

family

a glm family (see family for more details)

weights

\(n \times m\) matrix of weighting values

offset

\(n \times m\) matrix of offset values

parallel

if TRUE, allows for parallel computing using the foreach package

nthreads

number of cores to be used in parallel (only if parallel=TRUE)

clust

registered cluster to be used for distributing the computations (only if parallel=TRUE)