Estimate the coefficients of a vector generalized linear model via parallel iterative re-weighted least squares. Computations can be performed in parallel to speed up the execution.
vglm.fit.coef(
Y,
X,
family = gaussian(),
weights = NULL,
offset = NULL,
parallel = FALSE,
nthreads = 1,
clust = NULL
)\(n \times m\) matrix of response variables
\(n \times p\) matrix of covariates
a glm family (see family for more details)
\(n \times m\) matrix of weighting values
\(n \times m\) matrix of offset values
if TRUE, allows for parallel computing using the foreach package
number of cores to be used in parallel (only if parallel=TRUE)
registered cluster to be used for distributing the computations (only if parallel=TRUE)